package com.ruoyi.traceability.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.traceability.mapper.ProUprecordMapper;
import com.ruoyi.traceability.domain.ProUprecord;
import com.ruoyi.traceability.service.IProUprecordService;
import com.ruoyi.common.core.text.Convert;

/**
 * 上料记录Service业务层处理
 * 
 * @author wenjy
 * @date 2022-11-09
 */
@Service
public class ProUprecordServiceImpl implements IProUprecordService 
{
    @Autowired
    private ProUprecordMapper proUprecordMapper;

    /**
     * 查询上料记录
     * 
     * @param id 上料记录主键
     * @return 上料记录
     */
    @Override
    public ProUprecord selectProUprecordById(Long id)
    {
        return proUprecordMapper.selectProUprecordById(id);
    }

    /**
     * 查询上料记录列表
     * 
     * @param proUprecord 上料记录
     * @return 上料记录
     */
    @Override
    public List<ProUprecord> selectProUprecordList(ProUprecord proUprecord)
    {
        return proUprecordMapper.selectProUprecordList(proUprecord);
    }

    /**
     * 新增上料记录
     * 
     * @param proUprecord 上料记录
     * @return 结果
     */
    @Override
    public int insertProUprecord(ProUprecord proUprecord)
    {
        return proUprecordMapper.insertProUprecord(proUprecord);
    }

    /**
     * 修改上料记录
     * 
     * @param proUprecord 上料记录
     * @return 结果
     */
    @Override
    public int updateProUprecord(ProUprecord proUprecord)
    {
        return proUprecordMapper.updateProUprecord(proUprecord);
    }

    /**
     * 批量删除上料记录
     * 
     * @param ids 需要删除的上料记录主键
     * @return 结果
     */
    @Override
    public int deleteProUprecordByIds(String ids)
    {
        return proUprecordMapper.deleteProUprecordByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除上料记录信息
     * 
     * @param id 上料记录主键
     * @return 结果
     */
    @Override
    public int deleteProUprecordById(Long id)
    {
        return proUprecordMapper.deleteProUprecordById(id);
    }
}
